summaryrefslogtreecommitdiffstats
path: root/ppapi/c
diff options
context:
space:
mode:
Diffstat (limited to 'ppapi/c')
-rw-r--r--ppapi/c/private/ppb_content_decryptor_private.h22
-rw-r--r--ppapi/c/private/ppp_content_decryptor_private.h14
2 files changed, 18 insertions, 18 deletions
diff --git a/ppapi/c/private/ppb_content_decryptor_private.h b/ppapi/c/private/ppb_content_decryptor_private.h
index 18fa715..58492a0 100644
--- a/ppapi/c/private/ppb_content_decryptor_private.h
+++ b/ppapi/c/private/ppb_content_decryptor_private.h
@@ -4,7 +4,7 @@
*/
/* From private/ppb_content_decryptor_private.idl,
- * modified Wed Nov 27 14:10:24 2013.
+ * modified Fri Dec 6 12:16:22 2013.
*/
#ifndef PPAPI_C_PRIVATE_PPB_CONTENT_DECRYPTOR_PRIVATE_H_
@@ -46,7 +46,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
/**
* A session has been created by the CDM.
*
* @param[in] reference_id A reference for the session for which the CDM
* created a session.
*
* @param[in] web_session_id A <code>PP_Var</code> of type
@@ -55,7 +55,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
*
*/
void (*SessionCreated)(PP_Instance instance,
- uint32_t reference_id,
+ uint32_t session_id,
struct PP_Var web_session_id);
/**
* A message or request has been generated for key_system in the CDM, and
@@ -71,7 +71,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
* of <code>UpdateSession()</code> and <code>SessionMessage()</code> calls
* required to prepare for decryption.
*
* @param[in] reference_id A reference for the session for which the message
* is intended.
*
* @param[in] message A <code>PP_Var</code> of type
@@ -82,7 +82,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
* message.
*/
void (*SessionMessage)(PP_Instance instance,
- uint32_t reference_id,
+ uint32_t session_id,
struct PP_Var message,
struct PP_Var destination_url);
/**
@@ -97,23 +97,23 @@ struct PPB_ContentDecryptor_Private_0_9 {
* The CDM must call <code>SessionReady()</code> when the sequence is
* completed, and, in response, the browser must notify the web application.
*
* @param[in] reference_id A reference for the session that is ready.
*/
- void (*SessionReady)(PP_Instance instance, uint32_t reference_id);
+ void (*SessionReady)(PP_Instance instance, uint32_t session_id);
/**
* The session has been closed as the result of a call to the
* <code>ReleaseSession()</code> method on the
* <code>PPP_ContentDecryptor_Private</code> interface, or due to other
* factors as determined by the CDM.
*
* @param[in] reference_id A reference for the session that is closed.
*/
- void (*SessionClosed)(PP_Instance instance, uint32_t reference_id);
+ void (*SessionClosed)(PP_Instance instance, uint32_t session_id);
/**
* An error occurred in a <code>PPP_ContentDecryptor_Private</code> method,
* or within the plugin implementing the interface.
*
* @param[in] reference_id A reference for the session for which the error
* is intended.
*
* @param[in] media_error A MediaKeyError.
@@ -121,7 +121,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
* @param[in] system_error A system error code.
*/
void (*SessionError)(PP_Instance instance,
- uint32_t reference_id,
+ uint32_t session_id,
int32_t media_error,
int32_t system_code);
/**
@@ -46,7 +46,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
* A session has been created by the CDM.
*
- * @param[in] reference_id A reference for the session for which the CDM
+ * @param[in] session_id Identifies the session for which the CDM
* created a session.
*
@@ -71,7 +71,7 @@ struct PPB_ContentDecryptor_Private_0_9 {
* required to prepare for decryption.
*
- * @param[in] reference_id A reference for the session for which the message
+ * @param[in] session_id Identifies the session for which the message
* is intended.
*
@@ -97,23 +97,23 @@ struct PPB_ContentDecryptor_Private_0_9 {
* completed, and, in response, the browser must notify the web application.
*
- * @param[in] reference_id A reference for the session that is ready.
+ * @param[in] session_id Identifies the session that is ready.
*/
@@ -97,23 +97,23 @@ struct PPB_ContentDecryptor_Private_0_9 {
* factors as determined by the CDM.
*
- * @param[in] reference_id A reference for the session that is closed.
+ * @param[in] session_id Identifies the session that is closed.
*/
@@ -97,23 +97,23 @@ struct PPB_ContentDecryptor_Private_0_9 {
* or within the plugin implementing the interface.
*
- * @param[in] reference_id A reference for the session for which the error
+ * @param[in] session_id Identifies the session for which the error
* is intended.
*
diff --git a/ppapi/c/private/ppp_content_decryptor_private.h b/ppapi/c/private/ppp_content_decryptor_private.h
index 1873abc..27d172d 100644
--- a/ppapi/c/private/ppp_content_decryptor_private.h
+++ b/ppapi/c/private/ppp_content_decryptor_private.h
@@ -4,7 +4,7 @@
*/
/* From private/ppp_content_decryptor_private.idl,
- * modified Wed Nov 27 15:42:55 2013.
+ * modified Tue Dec 3 17:05:10 2013.
*/
#ifndef PPAPI_C_PRIVATE_PPP_CONTENT_DECRYPTOR_PRIVATE_H_
@@ -60,7 +60,7 @@ struct PPP_ContentDecryptor_Private_0_9 {
* browser by the CDM via <code>SessionCreated()</code> on the
* <code>PPB_ContentDecryptor_Private</code> interface.
*
* @param[in] reference_id A reference for the session for which a session
* should be generated.
*
* @param[in] type A <code>PP_Var</code> of type
@@ -71,7 +71,7 @@ struct PPP_ContentDecryptor_Private_0_9 {
* initialization data.
*/
void (*CreateSession)(PP_Instance instance,
- uint32_t reference_id,
+ uint32_t session_id,
struct PP_Var type,
struct PP_Var init_data);
/**
@@ -86,22 +86,22 @@ struct PPP_ContentDecryptor_Private_0_9 {
* <code>PPB_ContentDecryptor_Private</code> interface, and the browser
* must notify the web application.
*
* @param[in] reference_id A reference for the session to update.
*
* @param[in] response A <code>PP_Var</code> of type
* <code>PP_VARTYPE_ARRAYBUFFER</code> containing the license or other
* message for the given session ID.
*/
void (*UpdateSession)(PP_Instance instance,
- uint32_t reference_id,
+ uint32_t session_id,
struct PP_Var response);
/**
* Release the specified session and related resources.
*
* @param[in] reference_id A reference for the session that should be
* released.
*/
- void (*ReleaseSession)(PP_Instance instance, uint32_t reference_id);
+ void (*ReleaseSession)(PP_Instance instance, uint32_t session_id);
/**
* Decrypts the block and returns the unencrypted block via
* <code>DeliverBlock()</code> on the
@@ -60,7 +60,7 @@ struct PPP_ContentDecryptor_Private_0_9 {
* <code>PPB_ContentDecryptor_Private</code> interface.
*
- * @param[in] reference_id A reference for the session for which a session
+ * @param[in] session_id A reference for the session for which a session
* should be generated.
*
@@ -86,22 +86,22 @@ struct PPP_ContentDecryptor_Private_0_9 {
* must notify the web application.
*
- * @param[in] reference_id A reference for the session to update.
+ * @param[in] session_id A reference for the session to update.
*
* @param[in] response A <code>PP_Var</code> of type
@@ -86,22 +86,22 @@ struct PPP_ContentDecryptor_Private_0_9 {
* Release the specified session and related resources.
*
- * @param[in] reference_id A reference for the session that should be
+ * @param[in] session_id A reference for the session that should be
* released.
*/